@@ -25,7 +25,7 @@ if sys.version_info >= (3, 0, 0):
     basestring = str
 
 
-__version__ = '0.3.0'
+__version__ = '0.3.1'
 __all__ = ['encode', 'decode', 'DecodeError']
 
 
@@ -205,10 +205,12 @@ def base64url_encode(input):
 
 
 def header(jwt):
+    if isinstance(jwt, unicode):
+        jwt = jwt.encode('utf-8')
     header_segment = jwt.split(b'.', 1)[0]
     try:
-        header_data = base64url_decode(header_segment).decode('utf-8')
-        return json.loads(header_data)
+        header_data = base64url_decode(header_segment)
+        return json.loads(header_data.decode('utf-8'))
     except (ValueError, TypeError):
         raise DecodeError('Invalid header encoding')
 
